<?php

namespace Drupal\slimpay_api\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Slimpay API related settings form.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'slimpay_api_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'slimpay_api.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);
    $config = $this->config('slimpay_api.settings');

    $form['api_url'] = [
      '#type' => 'radios',
      '#title' => $this->t('Server'),
      '#default_value' => $config->get('api_url'),
      '#options' => [
        'https://api.preprod.slimpay.com' => $this->t('Preprod'),
        'https://api.slimpay.net' => $this->t('Prod'),
      ],
      '#required' => TRUE,
    ];
    $form['app_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('App ID'),
      '#default_value' => $config->get('app_id'),
      '#required' => TRUE,
    ];
    $form['app_secret'] = [
      '#type' => 'textfield',
      '#title' => $this->t('App Secret'),
      '#default_value' => $config->get('app_secret'),
      '#required' => TRUE,
    ];
    $form['creditor'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Creditor Reference'),
      '#default_value' => $config->get('creditor'),
      '#required' => TRUE,
    ];
    $form['payment_scheme'] = [
      '#type' => 'radios',
      '#title' => $this->t('paymentScheme'),
      '#default_value' => $config->get('payment_scheme'),
      '#options' => [
        'SEPA.DIRECT_DEBIT.CORE' => 'SEPA.DIRECT_DEBIT.CORE',
        'SEPA.DIRECT_DEBIT.B2B' => 'SEPA.DIRECT_DEBIT.B2B',
        'BACS.DIRECT_DEBIT' => 'BACS.DIRECT_DEBIT',
      ],
      '#required' => TRUE,
    ];
    $form['template'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Document Template'),
      '#default_value' => $config->get('template'),
      '#required' => TRUE,
    ];
    $form['iframe_mode'] = [
      '#type' => 'radios',
      '#title' => $this->t('Iframe mode'),
      '#default_value' => $config->get('iframe_mode'),
      '#options' => [
        'iframepopin' => 'Popin',
        'iframeembedded' => 'Embedded',
      ],
      '#required' => TRUE,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('slimpay_api.settings')
      ->set('api_url', $form_state->getValue('api_url'))
      ->set('app_id', $form_state->getValue('app_id'))
      ->set('app_secret', $form_state->getValue('app_secret'))
      ->set('creditor', $form_state->getValue('creditor'))
      ->set('payment_scheme', $form_state->getValue('payment_scheme'))
      ->set('template', $form_state->getValue('template'))
      ->set('iframe_mode', $form_state->getValue('iframe_mode'))
      ->save();
  }

}
